@@ -6,18 +6,17 @@ doExposureControl <- function(
   exposure_record, segment_record,
   o, j,
   current_theta,
-  eligible_flag,
-  config,
+  eligibility_flag,
   constants
 ) {
 
-  if (!constants$use_eligibility_control) {
+  if (!constants$use_exposure_control) {
     return(exposure_record)
   }
 
   segment_of                 <- getSegmentOf(o, constants)
   segment_record             <- updateSegmentRecord(segment_record, segment_of, j)
-  eligible_flag_in_final_theta_segment   <- getEligibleFlagInSegment(eligible_flag, segment_of$final_theta_est, constants)
+  eligibility_flag_in_final_theta_segment <- getEligibilityFlagInSegment(eligibility_flag, segment_of$final_theta_est, constants)
 
   if (constants$exposure_control_method %in% c("ELIGIBILITY")) {
 
@@ -29,8 +28,8 @@ doExposureControl <- function(
     exposure_record   <- incrementN(exposure_record, segments_to_apply, segment_prob, constants)
     exposure_record   <- incrementPhi(exposure_record, segments_to_apply, segment_prob, theta_is_feasible)
     exposure_record   <- incrementAlpha(exposure_record, segments_to_apply, segment_prob, o, constants)
-    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligible_flag, theta_is_feasible, constants)
-    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob, segment_of$visited, eligible_flag_in_final_theta_segment, o, constants)
+    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligibility_flag, theta_is_feasible, constants)
+    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob, segment_of$visited, eligibility_flag_in_final_theta_segment, o, constants)
     exposure_record   <- updateEligibilityRates(exposure_record, constants)
     exposure_record   <- clipEligibilityRates(exposure_record, constants)
     return(exposure_record)
@@ -45,8 +44,8 @@ doExposureControl <- function(
     exposure_record   <- incrementN(exposure_record, segments_to_apply, segment_prob, constants)
   # exposure_record   <- incrementPhi(exposure_record, segments_to_apply, segment_prob, TRUE) # is not called for the purpose of code optimization; see comments in incrementPhi()
     exposure_record   <- incrementAlpha(exposure_record, segments_to_apply, segment_prob, o, constants)
-    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligible_flag, TRUE, constants)
-    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob, segment_of$visited, eligible_flag_in_final_theta_segment, o, constants)
+    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligibility_flag, TRUE, constants)
+    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob, segment_of$visited, eligibility_flag_in_final_theta_segment, o, constants)
     exposure_record   <- updateEligibilityRates(exposure_record, constants)
     exposure_record   <- clipEligibilityRates(exposure_record, constants)
     return(exposure_record)
@@ -61,8 +60,8 @@ doExposureControl <- function(
     exposure_record   <- incrementN(exposure_record, segments_to_apply, segment_prob, constants)
   # exposure_record   <- incrementPhi(exposure_record, segments_to_apply, segment_prob, TRUE) # is not called for the purpose of code optimization; see comments in incrementPhi()
     exposure_record   <- incrementAlpha(exposure_record, segments_to_apply, segment_prob, o, constants)
-    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligible_flag, TRUE, constants)
-    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob[segment_of$final_theta_est], segment_of$visited, eligible_flag_in_final_theta_segment, o, constants)
+    exposure_record   <- incrementRho(exposure_record, segments_to_apply, segment_prob, eligibility_flag, TRUE, constants)
+    exposure_record   <- adjustAlphaToReduceSpike(exposure_record, segment_prob[segment_of$final_theta_est], segment_of$visited, eligibility_flag_in_final_theta_segment, o, constants)
     exposure_record   <- updateEligibilityRates(exposure_record, constants)
     exposure_record   <- clipEligibilityRates(exposure_record, constants)
     return(exposure_record)
@@ -95,7 +94,7 @@ initializeSegmentRecord <- function(constants) {
 
   o <- list()
 
-  if (!constants$use_eligibility_control) {
+  if (!constants$use_exposure_control) {
     return(o)
   }
 
@@ -111,6 +110,12 @@ initializeSegmentRecord <- function(constants) {
 #' @noRd
 initializeExposureRecord <- function(exposure_control, constants) {
 
+  # the j subscript used here is intentional and should not be removed.
+  # the notation scheme is from van der Linden, W. J., & Veldkamp, B. P. (2007).
+  # for example, a_ijk here is interpreted as:
+  # - the number of examinees until j-th examinee who was in theta segment k and was administered item i.
+  # - see how this interpretation does not imply the variable is a three-dimensional array.
+
   o <- list()
 
   ni <- constants$ni
@@ -134,7 +139,7 @@ initializeExposureRecord <- function(exposure_control, constants) {
     o$r_ijk_nofade <- o$r_ijk
   }
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     return(o)
   }
 
@@ -158,7 +163,7 @@ getInitialEligibilityStats <- function(o, initial_stats, constants) {
   o$a_ijk <- initial_stats$a_ijk
   o$r_ijk <- initial_stats$r_ijk
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     return(o)
   }
 
@@ -179,22 +184,22 @@ initializeExposureRecordSegmentwise <- function(constants) {
   n_segment     <- constants$n_segment
   fading_factor <- constants$fading_factor
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     o$a_g_i <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$e_g_i <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
   }
-  if (constants$set_based) {
+  if (constants$group_by_stimulus) {
     o$a_g_i <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$e_g_i <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$a_g_s <- replicate(n_segment, matrix(0, nrow = nj, ncol = ns), simplify = FALSE)
     o$e_g_s <- replicate(n_segment, matrix(0, nrow = nj, ncol = ns), simplify = FALSE)
   }
 
-  if (fading_factor != 1 & !constants$set_based) {
+  if (fading_factor != 1 & !constants$group_by_stimulus) {
     o$a_g_i_nofade <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$e_g_i_nofade <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
   }
-  if (fading_factor != 1 & constants$set_based) {
+  if (fading_factor != 1 & constants$group_by_stimulus) {
     o$a_g_i_nofade <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$e_g_i_nofade <- replicate(n_segment, matrix(0, nrow = nj, ncol = ni), simplify = FALSE)
     o$a_g_s_nofade <- replicate(n_segment, matrix(0, nrow = nj, ncol = ns), simplify = FALSE)
@@ -270,7 +275,7 @@ updateExposureRecordSegmentwise <- function(o, j, x, constants) {
     }
   }
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     return(o)
   }
 
@@ -291,11 +296,11 @@ updateExposureRecordSegmentwise <- function(o, j, x, constants) {
 #' @noRd
 initializeUsageMatrix <- function(constants) {
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     o <- matrix(FALSE, nrow = constants$nj, ncol = constants$ni)
     return(o)
   }
-  if (constants$set_based) {
+  if (constants$group_by_stimulus) {
     o <- matrix(FALSE, nrow = constants$nj, ncol = constants$nv)
     return(o)
   }
@@ -303,31 +308,31 @@ initializeUsageMatrix <- function(constants) {
 }
 
 #' @noRd
-updateUsageMatrix <- function(o, j, x, constants) {
+updateUsageMatrix <- function(usage_matrix, j, x, constants) {
 
-  o[j, x@administered_item_index] <- TRUE
+  usage_matrix[j, x@administered_item_index] <- TRUE
 
-  if (!constants$set_based) {
-    return(o)
+  if (!constants$group_by_stimulus) {
+    return(usage_matrix)
   }
 
-  o[j, constants$ni + x@administered_stimulus_index] <- TRUE
+  usage_matrix[j, constants$ni + x@administered_stimulus_index] <- TRUE
 
-  return(o)
+  return(usage_matrix)
 
 }
 
 #' @noRd
 aggregateUsageMatrix <- function(usage_matrix, constants, constraints) {
 
-  if (!constants$set_based) {
+  if (!constants$group_by_stimulus) {
     o <- matrix(NA, constants$ni, 2)
     colnames(o) <- c("Item", "Item ER")
     o[, 1] <- 1:constants$ni
     o[, 2] <- apply(usage_matrix, 2, sum) / constants$nj
     return(o)
   }
-  if (constants$set_based) {
+  if (constants$group_by_stimulus) {
     o <- matrix(NA, constants$ni, 4)
     colnames(o) <- c("Item", "Stimulus", "Item ER", "Stimulus ER")
     x <- apply(usage_matrix, 2, sum) / constants$nj
